##  Rejecting Discovered Items
You can ignore a discovered item if you don't want to link it to a fact sheet. Here are some reasons for rejecting a discovered SaaS item:
  * It is not relevant to your organization's SaaS inventory from an enterprise architecture perspective.
  * It is a duplicate instance of the same SaaS discovered by different integration sources.
  * It pertains to outdated or discontinued services that are no longer in use.
  * It is a test instance.
  * You want to overwrite the information in the linked fact sheet. Rejecting a linked item effectively unlinks it and stops updates from the reference catalog.


To reject discovered a discovered item, follow these steps:
  1. From the list, click on the discovered SaaS item that needs to be rejected. This opens the side panel.
  2. In the side panel, click Reject.


Rejected items are then listed in the Rejected tab, allowing you to review and relink them if needed.
